@@ -12,13 +12,6 @@
 #include <sys/wait.h>
 #include <sys/types.h>
 
-/* since we never use getc_unlocked now we should really
- * do something to speed up read_one_line
- */
-#  define flockfile(f) (void)1
-#  define funlockfile(f) (void)1
-#  define getc_unlocked(f) getc(f)
-
 #ifdef NATIVE_WIN32
 
 #define STRICT
@@ -43,8 +36,6 @@ read_one_line (FILE *stream, GString *str)
   gboolean quoted = FALSE;
   gboolean comment = FALSE;
   int n_read = 0;
-  
-  flockfile (stream);
 
   g_string_truncate (str, 0);
   
@@ -52,7 +43,7 @@ read_one_line (FILE *stream, GString *str)
     {
       int c;
       
-      c = getc_unlocked (stream);
+      c = getc (stream);
 
       if (c == EOF)
 	{
@@ -76,7 +67,7 @@ read_one_line (FILE *stream, GString *str)
 	    case '\r':
 	    case '\n':
 	      {
-		int next_c = getc_unlocked (stream);
+		int next_c = getc (stream);
 
 		if (!(c == EOF ||
 		      (c == '\r' && next_c == '\n') ||
@@ -103,7 +94,7 @@ read_one_line (FILE *stream, GString *str)
 	      break;
 	    case '\n':
 	      {
-		int next_c = getc_unlocked (stream);
+		int next_c = getc (stream);
 
 		if (!(c == EOF ||
 		      (c == '\r' && next_c == '\n') ||
@@ -121,8 +112,6 @@ read_one_line (FILE *stream, GString *str)
 
  done:
 
-  funlockfile (stream);
-
   return n_read > 0;
 }
 
@@ -742,6 +731,8 @@ parse_cflags (Package *pkg, const char *str, const char *path)
         }
       else
         {
+          if (other->len > 0)
+            g_string_append (other, " ");
           g_string_append (other, arg);
         }
 
@@ -805,7 +796,8 @@ parse_line (Package *pkg, const char *untrimmed, const char *path)
         parse_requires (pkg, p, path);
       else if (strcmp (tag, "Libs") == 0)
         parse_libs (pkg, p, path);
-      else if (strcmp (tag, "Cflags") == 0)
+      else if (strcmp (tag, "Cflags") == 0 ||
+               strcmp (tag, "CFlags") == 0)
         parse_cflags (pkg, p, path);
       else if (strcmp (tag, "Conflicts") == 0)
         parse_conflicts (pkg, p, path);
@@ -949,7 +941,10 @@ get_compat_package (const char *name)
 {
   Package *pkg;
 
-  debug_spew ("Looking for '%s' using old-style -config scripts\n", name);
+  if (name_ends_in_uninstalled (name))
+    debug_spew ("Suspiciously looking for compat package for -uninstalled: %s\n", name);
+  
+  debug_spew ("Looking for '%s' using legacy -config scripts\n", name);
   
   pkg = g_new0 (Package, 1);
   
@@ -1005,6 +1000,33 @@ get_compat_package (const char *name)
       parse_cflags (pkg, output, "gtk-config");
       g_free (output);
 
+      return pkg;
+    }
+  else if (strcmp (name, "libgnomevfs") == 0)
+    {
+      char *output;
+
+      debug_spew ("Calling gnome-vfs-config\n");
+      
+      pkg->version = backticks ("gnome-vfs-config --version");
+      if (pkg->version == NULL)
+        {
+          g_free (pkg);
+          return NULL;
+        }
+      
+      pkg->name = g_strdup ("GNOME VFS");
+      pkg->key = g_strdup ("libgnomevfs");
+      pkg->description = g_strdup ("GNOME Virtual File System");
+
+      output = backticks ("gnome-vfs-config --libs");
+      parse_libs (pkg, output, "gnome-vfs-config");
+      g_free (output);
+
+      output = backticks ("gnome-vfs-config --cflags");
+      parse_cflags (pkg, output, "gnome-vfs-config");
+      g_free (output);
+
       return pkg;
     }
   else if (strcmp (name, "imlib") == 0)
