@@ -13,6 +13,7 @@
 # endif
 #endif
 
+#include <sys/types.h>
 #include <dirent.h>
 #include <string.h>
 #include <errno.h>
@@ -52,10 +53,10 @@ ends_in_dotpc (const char *str)
 }
 
 /* strlen ("uninstalled") */
-#define UNINSTALLED_LEN 11 
+#define UNINSTALLED_LEN 11
 
-static gboolean
-ends_in_uninstalled (const char *str)
+gboolean
+name_ends_in_uninstalled (const char *str)
 {
   int len = strlen (str);
   
@@ -161,7 +162,7 @@ file_readable (const char *path)
 
 
 static Package *
-internal_get_package (const char *name, gboolean warn)
+internal_get_package (const char *name, gboolean warn, gboolean check_compat)
 {
   Package *pkg = NULL;
   const char *location;
@@ -183,13 +184,13 @@ internal_get_package (const char *name, gboolean warn)
     {
       /* See if we should auto-prefer the uninstalled version */
       if (!disable_uninstalled &&
-          !ends_in_uninstalled (name))
+          !name_ends_in_uninstalled (name))
         {
           char *un;
 
           un = g_strconcat (name, "-uninstalled", NULL);
 
-          pkg = internal_get_package (un, FALSE);
+          pkg = internal_get_package (un, FALSE, FALSE);
 
           g_free (un);
           
@@ -201,28 +202,33 @@ internal_get_package (const char *name, gboolean warn)
         }
       
       location = g_hash_table_lookup (locations, name);
-      debug_spew ("Reading '%s' from file '%s'\n", name, location);
     }
   
-  if (location == NULL)
+  if (location == NULL && check_compat)
     {
       pkg = get_compat_package (name);
-      
-      if (pkg == NULL)
-        {
-          if (warn)
-            verbose_error ("Package %s was not found in the pkg-config search path.\n"
-                           "Perhaps you should add the directory containing `%s.pc'\n"
-                           "to the PKG_CONFIG_PATH environment variable\n",
-                           name, name);
-        }
 
-      debug_spew ("Returning values for '%s' from a legacy -config script\n",
-                  name);
+      if (pkg)
+        {
+          debug_spew ("Returning values for '%s' from a legacy -config script\n",
+                      name);
+          
+          return pkg;
+        }
+    }
       
-      return pkg;
+  if (location == NULL)
+    {
+      if (warn)
+        verbose_error ("Package %s was not found in the pkg-config search path.\n"
+                       "Perhaps you should add the directory containing `%s.pc'\n"
+                       "to the PKG_CONFIG_PATH environment variable\n",
+                       name, name);
+
+      return NULL;
     }
 
+  debug_spew ("Reading '%s' from file '%s'\n", name, location);
   pkg = parse_package_file (location);
   
   if (pkg == NULL)
@@ -264,7 +270,7 @@ internal_get_package (const char *name, gboolean warn)
 Package *
 get_package (const char *name)
 {
-  return internal_get_package (name, TRUE);
+  return internal_get_package (name, TRUE, TRUE);
 }
 
 static GSList*
